# Quickstart-VDK

This is the first VDK packaging that users would install to play around with.

It packages:

* Plugin for a local database to get started quickly
* Plugin for job management (vdk-control-cli)
* Plugin for local Control Service installation (vdk-server)

See also [Versatile Data Kit Getting Started](https://github.com/vmware/versatile-data-kit/wiki/Getting-Started).
